@@ -1,6 +1,11 @@
 ## ----echo = FALSE-------------------------------------------------------------
-knitr::opts_chunk$set(fig.width = 7, fig.height = 7, message = FALSE, warning = FALSE,
-                      eval = requireNamespace("tm", quietly = TRUE) && requireNamespace("quanteda", quietly = TRUE) && requireNamespace("topicmodels", quietly = TRUE))
+knitr::opts_chunk$set(
+  fig.width = 7, fig.height = 7, 
+  message = FALSE, warning = FALSE,
+  eval = requireNamespace("tm", quietly = TRUE) && requireNamespace("quanteda", quietly = TRUE) && requireNamespace("topicmodels", quietly = TRUE) && requireNamespace("ggplot2", quietly = TRUE)
+  )
+
+## ----echo=FALSE---------------------------------------------------------------
 library(ggplot2)
 theme_set(theme_bw())
 
