@@ -1,4 +1,3 @@
-context("Sparse tidiers")
 
 test_that("Can tidy DocumentTermMatrices and TermDocumentMatrices", {
   if (require("tm", quietly = TRUE)) {
@@ -10,14 +9,14 @@ test_that("Can tidy DocumentTermMatrices and TermDocumentMatrices", {
     ovid_dtm <- DocumentTermMatrix(ovid)
     ovid_dtm_td <- tidy(ovid_dtm)
 
-    expect_is(ovid_dtm_td, "tbl_df")
+    expect_s3_class(ovid_dtm_td, "tbl_df")
     expect_equal(sort(unique(ovid_dtm_td$document)), sort(rownames(ovid_dtm)))
     expect_equal(sort(unique(ovid_dtm_td$term)), sort(colnames(ovid_dtm)))
 
     ovid_tdm <- TermDocumentMatrix(ovid)
     ovid_tdm_td <- tidy(ovid_tdm)
 
-    expect_is(ovid_tdm_td, "tbl_df")
+    expect_s3_class(ovid_tdm_td, "tbl_df")
     expect_equal(sort(unique(ovid_tdm_td$document)), sort(colnames(ovid_tdm)))
     expect_equal(sort(unique(ovid_tdm_td$term)), sort(rownames(ovid_tdm)))
   }
@@ -29,7 +28,7 @@ test_that("Can tidy dfm from quanteda", {
     dfm_obj <- quanteda::dfm(quanteda::tokens(quanteda::data_corpus_inaugural))
     dfm_obj_td <- tidy(dfm_obj)
 
-    expect_is(dfm_obj_td, "tbl_df")
+    expect_s3_class(dfm_obj_td, "tbl_df")
     expect_equal(sort(unique(dfm_obj_td$document)), sort(rownames(dfm_obj)))
     expect_equal(sort(unique(dfm_obj_td$term)), sort(colnames(dfm_obj)))
   }
